<?php
/**
 * This is the VW Accordion loader class.
 */
if ( ! class_exists( 'VW_Accordion_Loader' ) ) {

class VW_Accordion_Loader {

	private static $instance;

    public static function forge() {
        if (!isset(self::$instance)) {
            $className = __CLASS__;
            self::$instance = new $className;
        }
        return self::$instance;
    }
	
	/**
     * PHP5 constructor method.
     *
     * This method loads other methods of the class.
     *
     * @return    void
     *
     * @access    private
     */
	private function __construct() {
		
		add_action('admin_enqueue_scripts', array(&$this, 'vw_accordion_admin_scripts'));

        if (is_admin()) {
			add_action('init', array(&$this, 'vw_accordion'), 1);
			add_action('add_meta_boxes', array(&$this, 'vw_accordion_meta_boxes_group'));
			add_action('admin_init', array(&$this, 'vw_accordion_meta_boxes_group'), 1);
			add_action('save_post', array(&$this, 'vw_accordion_meta_box_save'), 9, 1);
			add_action('save_post', array(&$this, 'vwac_settings_meta_box_save'), 9, 1);
		}
    }

	/**
     * Load admin scripts
     */
	public function vw_accordion_admin_scripts(){

		if(get_post_type()=="vw_accordion"){
			
			wp_enqueue_media();
			wp_enqueue_script('jquery-ui-datepicker');
			
			//Assets for color piker
			wp_enqueue_style( 'wp-color-picker' );
			wp_enqueue_script( 'wp-color-picker' ); 	

			wp_enqueue_style('vw-accordion-admin-style', VWAC_DIRECTORY_URL.'assets/css/vwac-admin-style.css');

			wp_enqueue_style('vw-accordion-remodal-css', VWAC_DIRECTORY_URL .'modal/remodal.css');

			wp_enqueue_style('vw-accordion-remodal-default-theme-css', VWAC_DIRECTORY_URL .'modal/remodal-default-theme.css');
		
			
			//Load font awesome for backend
			wp_enqueue_style('vw-accordion-font-awesome', VWAC_DIRECTORY_URL.'assets/css/font-awesome/css/font-awesome.min.css');

			// Icon picker Css and Js
			wp_enqueue_style('font-awesome-picker', VWAC_DIRECTORY_URL.'assets/css/fontawesome-iconpicker.css');
			wp_enqueue_script('font-icon-picker-js',VWAC_DIRECTORY_URL.'assets/js/fontawesome-iconpicker.js',array('jquery'));

			// Custom Js For Admin Page
			wp_enqueue_script( 'vw-accordion-custom-admin-js', VWAC_DIRECTORY_URL.'assets/js/custom-admin.js');

			wp_enqueue_script('remodal-min-js',VWAC_DIRECTORY_URL.'modal/remodal.min.js',array('jquery'), false, true);
	
		}
	}
	
	// Custom posttype Registeration
	public function vw_accordion() {
		require_once('register-cpt.php');
	}

	// Adding columns on postlist page
	function vw_accordion_columns( $columns ){
        $columns = array(
            'cb' => '<input type="checkbox" />',
            'title' => __( 'VW Accordion' ),
            'shortcode' => __( 'Shortcode for VW Accordion ' ),
            'date' => __( 'Date' )
        );
        return $columns;
    }

    // Add column for the shortcode
    function vw_accordion_manage_columns( $column, $post_id ){
        global $post;
        switch( $column ) {
          case 'shortcode' :
            echo '<input type="text" value="[vw_accordion id='.$post_id.']" readonly="readonly" />';
            break;
          default :
            break;
        }
    }
	
	// Additional meta boxes
	public function vw_accordion_meta_boxes_group(){

		// Create metabox for Add Accordion 
		add_meta_box('add_accordion', __('Add Accordion', VWAC_TEXT_DOMAIN), array(&$this, 'vwac_add_accordion_meta_box_function'), 'vw_accordion', 'normal', 'low' );

		add_meta_box('accordion_appearance_settings', __('Appearnace', VWAC_TEXT_DOMAIN), array(&$this, 'vwac_appearance_settings_meta_box_function'), 'vw_accordion', 'normal', 'low');

		// Create metabox for Shortcode
		add_meta_box ('accordion_shortcode_settings', __('Shortcode for VW Accordion', VWAC_TEXT_DOMAIN), array(&$this, 'vw_accordion_shortcode'), 'vw_accordion', 'normal', 'low');
		
		// Create metabox for rate us
		add_meta_box('accordion_rateus', __('Support', VWAC_TEXT_DOMAIN), array(&$this, 'vwac_support_meta_box_function'), 'vw_accordion', 'side', 'low');

	}
	
	// Add accordion metabox
	public function vwac_add_accordion_meta_box_function($post){
		require_once('add-accordion.php');
	}
	
	// Shortcode metabox
	public function vw_accordion_shortcode(){
		?>

		<h3><?php esc_html_e('Accordion Shortcode', 'vw_accordion'); ?></h3>
		<p><?php esc_html_e("Use below shortcode in any Page/Post to publish your Accordion", VWAC_TEXT_DOMAIN);?></p>
		<code><?php echo "[vw_accordion id=". get_the_ID() ."]"; ?></code>
		
		<?php 
	}

	public function vwac_appearance_settings_meta_box_function($post){
		require('additional-settings.php');
	}
	
	// Save all the fields data
	public function vw_accordion_meta_box_save($PostID) {
		require('data-post/vwac-save-data.php');
    }
	
	// Help section
	public function vwac_support_meta_box_function(){ ?>
	    <div class="rate_us_box">

            <h2><?php echo esc_html('Rate us on wordpress.org', VWAC_TEXT_DOMAIN ); ?></h2>
            <p class="thank_msg"><?php echo esc_html('If you enjoy the plugin please rate us', 'vw-breadcrumb'); ?></p>
            <div class="star_dash">
              <?php for($i = 0; $i<5; $i++ ){ ?>
                <img src="<?php echo esc_attr( VWAC_DIRECTORY_URL . 'assets/img/star.png'); ?>">
              <?php } ?>
            </div>
            <p class="thank_btn"><a href="https://www.vwthemes.com/topic/reviews-and-testimonials/" target="_blank"><?php echo esc_html('Click Here', VWAC_TEXT_DOMAIN); ?></a></p>
            <p class="support_btn"><?php echo esc_html('If you face obstacle, do write at plugins support forum ', VWAC_TEXT_DOMAIN); ?><a href="https://www.vwthemes.com/support/" target="_blank"><?php echo esc_html('click here', VWAC_TEXT_DOMAIN); ?></a>
            </p>
            
        </div>
			
		<?php 
	}
	
	// save add settings data
	public function vwac_settings_meta_box_save($PostID){
		require('data-post/vwac-settings-save-data.php');
	}
} 
 
global $vw_accordion;

$vw_accordion = VW_Accordion_Loader::forge();

}